/// <reference types="@project-serum/anchor/node_modules/@solana/web3.js" />
import { PublicKey } from '@solana/web3.js';
import { CypherClient } from '../client';
import { CypherAccountState, ErrorCB, StateUpdateHandler } from '../types';
import { I80F48 } from '@blockworks-foundation/mango-client';
import { Pool } from './pool';
import { FuturesMarketViewer, PerpMarketViewer } from '../viewers';
import { CypherSubAccount } from './subAccount';
import { CacheAccount } from './cacheAccount';
export declare class CypherAccount {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: CypherAccountState;
    private _onStateUpdate?;
    private _errorCallback?;
    private _listener;
    constructor(client: CypherClient, address: PublicKey, state: CypherAccountState, _onStateUpdate?: StateUpdateHandler<CypherAccountState>, _errorCallback?: ErrorCB);
    static create(client: CypherClient, clearing: PublicKey, authority: PublicKey, accountNumber?: number): Promise<{
        account: PublicKey;
        ixs: import("@solana/web3.js").TransactionInstruction[];
        signers: any[];
    }>;
    static createWhitelisted(client: CypherClient, clearing: PublicKey, whitelist: PublicKey, authority: PublicKey, accountNumber?: number): Promise<{
        account: PublicKey;
        ixs: import("@solana/web3.js").TransactionInstruction[];
        signers: any[];
    }>;
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<CypherAccountState>, errorCallback?: ErrorCB): Promise<CypherAccount>;
    getSubAccounts(): PublicKey[];
    getCRatio(cacheAccount: CacheAccount, subAccounts: CypherSubAccount[]): {
        assetsValue: I80F48;
        assetsValueUnweighted: I80F48;
        volatileAssetsValue: I80F48;
        liabilitiesValue: I80F48;
        liabilitiesValueUnweighted: I80F48;
        volatileLiabilitiesValue: I80F48;
        cRatio: I80F48;
        volatileCRatio: I80F48;
    };
    subscribe(): void;
    private addListener;
    private removeListener;
    unsubscribe(): Promise<void>;
    getSpotOpenOrdersAddress(dexMarket: PublicKey, subAccount: PublicKey): PublicKey;
    getDerivativesOpenOrdersAddress(market: PublicKey): PublicKey;
    hasSpotOpenOrders(dexMarket: PublicKey, subAccount: PublicKey): Promise<boolean>;
    hasDerivativeOpenOrders(market: PublicKey): Promise<boolean>;
    getSpotMarketOrders(pool: Pool): Promise<import("@project-serum/serum/lib/market").Order[]>;
    getDerivativeMarketOrders(market: FuturesMarketViewer | PerpMarketViewer): Promise<import("./ordersAccount").Order[]>;
    getAssociatedTokenAddress(tokenMint: PublicKey): Promise<PublicKey>;
}
