/// <reference types="bn.js" />
import { PublicKey } from '@solana/web3.js';
import { Pool } from './pool';
import { CypherClient } from '../client';
import { BN } from '@project-serum/anchor';
import type { CreateFuturesMarketArgs, ErrorCB, FuturesMarketState, StateUpdateHandler } from '../types';
export declare class FuturesMarket {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: FuturesMarketState;
    private _onStateUpdate?;
    private _errorCallback?;
    private _listener;
    constructor(client: CypherClient, address: PublicKey, state: FuturesMarketState, _onStateUpdate?: StateUpdateHandler<FuturesMarketState>, _errorCallback?: ErrorCB);
    static create(client: CypherClient, authority: PublicKey, clearing: PublicKey, cacheAccount: PublicKey, quotePool: Pool, oracleProducts: PublicKey, args: CreateFuturesMarketArgs): Promise<PublicKey>;
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<FuturesMarketState>, errorCallback?: ErrorCB): Promise<FuturesMarket>;
    static loadAll(client: CypherClient): Promise<FuturesMarket[]>;
    get marketPrice(): BN;
    get positionsCount(): BN;
    get totalBorrows(): BN;
    get totalPurchased(): BN;
    get totalRaised(): BN;
    get tokenSupply(): BN;
    get marketActivatesAt(): Date;
    get marketExpiresAt(): Date;
    subscribe(): void;
    private addListener;
    private removeListener;
    unsubscribe(): Promise<void>;
}
