"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PoolNode = void 0;
const serum_1 = require("@project-serum/serum");
const mango_client_1 = require("@blockworks-foundation/mango-client");
class PoolNode {
    constructor(client, address, state, market, _onStateUpdate, _errorCallback) {
        this.client = client;
        this.address = address;
        this.state = state;
        this.market = market;
        this._onStateUpdate = _onStateUpdate;
        this._errorCallback = _errorCallback;
        _onStateUpdate && this.subscribe();
    }
    static async load(client, address, onStateUpdateHandler, errorCallback) {
        const state = (await client.accounts.poolNode.fetchNullable(address));
        return new PoolNode(client, address, state, null, onStateUpdateHandler, errorCallback);
    }
    static async loadAll(client) {
        const pools = [];
        const queryResult = await client.accounts.pool.all();
        for (const result of queryResult) {
            const market = await serum_1.Market.load(client.connection, result.account.dexMarket, {}, client.dexPID);
            pools.push(new PoolNode(client, result.publicKey, result.account, market));
        }
        return pools;
    }
    get deposits() {
        return new mango_client_1.I80F48(this.state.deposits);
    }
    get borrows() {
        return new mango_client_1.I80F48(this.state.borrows);
    }
    subscribe() {
        this.removeListener();
        try {
            this.addListener();
        }
        catch (error) {
            if (this._errorCallback) {
                this._errorCallback(error);
            }
        }
    }
    addListener() {
        this._listener = this.client.connection.onAccountChange(this.address, ({ data }) => {
            this.state = this.client.program.coder.accounts.decode('PoolNode', data);
            if (this._onStateUpdate) {
                this._onStateUpdate(this.state);
            }
        }, 'processed');
    }
    removeListener() {
        if (this._listener)
            this.client.connection.removeAccountChangeListener(this._listener);
    }
    async unsubscribe() {
        this.removeListener();
    }
}
exports.PoolNode = PoolNode;
//# sourceMappingURL=poolNode.js.map