/// <reference types="@project-serum/anchor/node_modules/@solana/web3.js" />
import { PublicKey } from '@solana/web3.js';
import { CypherClient } from '../client';
import { I80F48 } from '@blockworks-foundation/mango-client';
import type { CypherSubAccountState, DerivativePositionState, ErrorCB, SpotPositionState, StateUpdateHandler } from '../types';
import { CacheAccount } from './cacheAccount';
import { SpotPosition } from '../viewers/spotPosition';
import { DerivativePosition } from '../viewers/derivativePosition';
export declare class CypherSubAccount {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: CypherSubAccountState;
    private _onStateUpdate?;
    private _errorCallback?;
    private _listener;
    constructor(client: CypherClient, address: PublicKey, state: CypherSubAccountState, _onStateUpdate?: StateUpdateHandler<CypherSubAccountState>, _errorCallback?: ErrorCB);
    static create(client: CypherClient, authority: PublicKey, masterAccount: PublicKey, accountNumber?: number, accountAlias?: number[]): Promise<{
        subAccount: PublicKey;
        ixs: import("@solana/web3.js").TransactionInstruction[];
        signers: any[];
    }>;
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<CypherSubAccountState>, errorCallback?: ErrorCB): Promise<CypherSubAccount>;
    getSpotPosition(tokenMint: PublicKey): SpotPosition;
    getSpotPositionsInfo(): SpotPositionState[];
    getSpotPositions(): SpotPosition[];
    getDerivativePosition(market: PublicKey): DerivativePosition | null;
    getDerivativePositionsInfo(): DerivativePositionState[];
    getDerivativePositions(): DerivativePosition[];
    getAssetsValue(cacheAccount: CacheAccount): {
        assetsValueUnweighted: I80F48;
        assetsValue: I80F48;
        volatileAssetsValue: I80F48;
    };
    getLiabilitiesValue(cacheAccount: CacheAccount): {
        liabilitiesValueUnweighted: I80F48;
        liabilitiesValue: I80F48;
        volatileLiabilitiesValue: I80F48;
    };
    subscribe(): void;
    private addListener;
    private removeListener;
    unsubscribe(): Promise<void>;
}
