import { PublicKey, TransactionInstruction, Keypair } from '@solana/web3.js';
import { AnchorProvider, BN } from '@project-serum/anchor';
import { CancelOrderArgs, CreateClearingArgs, CreateFuturesMarketArgs, CreatePerpetualMarketArgs, CreatePoolArgs, NewDerivativeOrderArgs, NewSpotOrderArgs, CreateOracleProductsArgs, SubAccountMargining } from './types';
import { CypherClient } from './client';
export declare const makeCreatePublicClearingIx: (client: CypherClient, clearing: PublicKey, authority: PublicKey, payer: PublicKey, args: CreateClearingArgs) => Promise<TransactionInstruction>;
export declare const makeCreatePrivateClearingIx: (client: CypherClient, clearing: PublicKey, privateClearing: PublicKey, authority: PublicKey, payer: PublicKey, args: CreateClearingArgs) => Promise<TransactionInstruction>;
export declare const makeCreateAccountIx: (client: CypherClient, clearing: PublicKey, account: PublicKey, authority: PublicKey, payer: PublicKey, accountNumber: number, accountBump: number) => Promise<TransactionInstruction>;
export declare const makeCreateWhitelistedAccountIx: (client: CypherClient, clearing: PublicKey, whitelist: PublicKey, account: PublicKey, authority: PublicKey, payer: PublicKey, accountNumber: number, accountBump: number) => Promise<TransactionInstruction>;
export declare const makeCreateSubAccountIx: (client: CypherClient, masterAccount: PublicKey, subAccount: PublicKey, authority: PublicKey, payer: PublicKey, subAccountNumber: number, subAccountBump: number, subAccountAlias: number[]) => import("@project-serum/anchor/dist/cjs/program/namespace/methods").MethodsBuilder<import("./generated/types/cypher").Cypher, {
    name: "createSubAccount";
    accounts: [{
        name: "masterAccount";
        isMut: true;
        isSigner: false;
    }, {
        name: "subAccount";
        isMut: true;
        isSigner: false;
    }, {
        name: "authority";
        isMut: false;
        isSigner: true;
    }, {
        name: "payer";
        isMut: true;
        isSigner: true;
    }, {
        name: "systemProgram";
        isMut: false;
        isSigner: false;
    }];
    args: [{
        name: "subAccountNumber";
        type: "u8";
    }, {
        name: "subAccountBump";
        type: "u8";
    }, {
        name: "subAccountAlias";
        type: {
            array: ["u8", 32];
        };
    }];
} & {
    name: "createSubAccount";
}>;
export declare const makeCreateFuturesMarketIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, market: PublicKey, priceHistory: PublicKey, oracleProducts: PublicKey, quotePool: PublicKey, orderbook: PublicKey, bids: PublicKey, asks: PublicKey, eventQueue: PublicKey, authority: PublicKey, payer: PublicKey, args: CreateFuturesMarketArgs) => Promise<TransactionInstruction>;
export declare const makeCreatePerpMarketIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, market: PublicKey, oracleProducts: PublicKey, quotePool: PublicKey, orderbook: PublicKey, bids: PublicKey, asks: PublicKey, eventQueue: PublicKey, authority: PublicKey, payer: PublicKey, args: CreatePerpetualMarketArgs) => Promise<TransactionInstruction>;
export declare const makeCreatePoolIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, pool: PublicKey, poolNode: PublicKey, tokenMint: PublicKey, tokenVault: PublicKey, vaultSigner: PublicKey, oracleProducts: PublicKey, dexMarket: PublicKey, authority: PublicKey, payer: PublicKey, args: CreatePoolArgs) => Promise<TransactionInstruction>;
export declare const makeCreateOracleProductsIx: (client: CypherClient, cacheAccount: PublicKey, oracleProducts: PublicKey, authority: PublicKey, payer: PublicKey, productsArr: PublicKey[], args: CreateOracleProductsArgs) => Promise<TransactionInstruction>;
export declare const makeCreateDerivativesOrdersAccountIx: (client: CypherClient, masterAccount: PublicKey, market: PublicKey, openOrders: PublicKey, authority: PublicKey, payer: PublicKey) => Promise<TransactionInstruction>;
export declare const makeInitSpotOpenOrdersIx: (client: CypherClient, masterAccount: PublicKey, subAccount: PublicKey, pool: PublicKey, tokenMint: PublicKey, dexMarket: PublicKey, openOrders: PublicKey, authority: PublicKey, payer: PublicKey) => Promise<TransactionInstruction>;
export declare const makeCacheOraclePricesIx: (client: CypherClient, cacheAccount: PublicKey, oracleProducts: PublicKey, productsArr: PublicKey[], cacheIndex: BN, pool?: PublicKey, futuresMarket?: PublicKey) => Promise<TransactionInstruction>;
export declare const makeCloseSpotOpenOrdersIx: (client: CypherClient, masterAccount: PublicKey, subAccount: PublicKey, assetPool: PublicKey, tokenMint: PublicKey, dexMarket: PublicKey, openOrders: PublicKey, authority: PublicKey) => Promise<TransactionInstruction>;
export declare const makeSetAccountDelegateIx: (client: CypherClient, masterAccount: PublicKey, delegate: PublicKey, authority: PublicKey) => Promise<TransactionInstruction>;
export declare const makeSetSubAccountDelegateIx: (client: CypherClient, subAccount: PublicKey, delegate: PublicKey, authority: PublicKey) => Promise<TransactionInstruction>;
export declare const makeDepositFundsIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, pool: PublicKey, poolNode: PublicKey, sourceTokenAccount: PublicKey, tokenVault: PublicKey, tokenMint: PublicKey, authority: PublicKey, amount: BN) => Promise<TransactionInstruction>;
export declare const makeWithdrawFundsIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, pool: PublicKey, poolNode: PublicKey, tokenVault: PublicKey, vaultSigner: PublicKey, destinationTokenAccount: PublicKey, tokenMint: PublicKey, authority: PublicKey, amount: BN) => Promise<TransactionInstruction>;
export declare const makeNewFuturesOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, priceHistory: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: NewDerivativeOrderArgs) => Promise<TransactionInstruction>;
export declare const makeNewFuturesOrdersIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, priceHistory: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: NewDerivativeOrderArgs[]) => Promise<TransactionInstruction>;
export declare const makeCancelFuturesOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: CancelOrderArgs) => Promise<TransactionInstruction>;
export declare const makeCancelFuturesOrdersIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: CancelOrderArgs[]) => Promise<TransactionInstruction>;
export declare const makeSettleFuturesFundsIx: (client: CypherClient, cacheAccount: PublicKey, clearing: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, openOrders: PublicKey, market: PublicKey, quotePoolNode: PublicKey, authority: PublicKey) => Promise<TransactionInstruction>;
export declare const makeNewPerpOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: NewDerivativeOrderArgs) => Promise<TransactionInstruction>;
export declare const makeMultipleNewPerpOrdersIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: NewDerivativeOrderArgs[]) => Promise<TransactionInstruction>;
export declare const makeCancelPerpOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: CancelOrderArgs) => Promise<TransactionInstruction>;
export declare const makeCancelPerpOrdersIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, openOrders: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, bids: PublicKey, asks: PublicKey, quotePoolNode: PublicKey, authority: PublicKey, args: CancelOrderArgs[]) => Promise<TransactionInstruction>;
export declare const makeSettlePerpFundsIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, openOrders: PublicKey, market: PublicKey, quotePoolNode: PublicKey) => Promise<TransactionInstruction>;
export interface NewSpotOrderDexAccounts {
    market: PublicKey;
    openOrders: PublicKey;
    eventQueue: PublicKey;
    requestQueue: PublicKey;
    bids: PublicKey;
    asks: PublicKey;
    coinVault: PublicKey;
    pcVault: PublicKey;
    vaultSigner: PublicKey;
}
export declare const makeNewSpotOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, assetPoolNode: PublicKey, quotePoolNode: PublicKey, assetMint: PublicKey, assetVault: PublicKey, vaultSigner: PublicKey, quoteVault: PublicKey, authority: PublicKey, dexAccounts: NewSpotOrderDexAccounts, args: NewSpotOrderArgs) => Promise<TransactionInstruction>;
export interface CancelSpotOrderDexAccounts {
    market: PublicKey;
    openOrders: PublicKey;
    eventQueue: PublicKey;
    bids: PublicKey;
    asks: PublicKey;
    coinVault: PublicKey;
    pcVault: PublicKey;
    vaultSigner: PublicKey;
}
export declare const makeCancelSpotOrderIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, assetPoolNode: PublicKey, quotePoolNode: PublicKey, assetMint: PublicKey, assetVault: PublicKey, quoteVault: PublicKey, authority: PublicKey, dexAccounts: CancelSpotOrderDexAccounts, args: CancelOrderArgs) => Promise<TransactionInstruction>;
export interface SettleSpotFundsDexAccounts {
    market: PublicKey;
    openOrders: PublicKey;
    coinVault: PublicKey;
    pcVault: PublicKey;
    vaultSigner: PublicKey;
}
export declare const makeSettleSpotFundsIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, assetPoolNode: PublicKey, quotePoolNode: PublicKey, assetMint: PublicKey, assetVault: PublicKey, quoteVault: PublicKey, authority: PublicKey, dexAccounts: SettleSpotFundsDexAccounts) => import("@project-serum/anchor/dist/cjs/program/namespace/methods").MethodsBuilder<import("./generated/types/cypher").Cypher, {
    name: "settleSpotFunds";
    accounts: [{
        name: "clearing";
        isMut: false;
        isSigner: false;
    }, {
        name: "cacheAccount";
        isMut: false;
        isSigner: false;
    }, {
        name: "masterAccount";
        isMut: true;
        isSigner: false;
    }, {
        name: "subAccount";
        isMut: true;
        isSigner: false;
    }, {
        name: "assetPoolNode";
        isMut: true;
        isSigner: false;
    }, {
        name: "quotePoolNode";
        isMut: true;
        isSigner: false;
    }, {
        name: "assetMint";
        isMut: false;
        isSigner: false;
    }, {
        name: "assetVault";
        isMut: true;
        isSigner: false;
    }, {
        name: "quoteVault";
        isMut: true;
        isSigner: false;
    }, {
        name: "authority";
        isMut: false;
        isSigner: true;
    }, {
        name: "dex";
        accounts: [{
            name: "market";
            isMut: true;
            isSigner: false;
        }, {
            name: "openOrders";
            isMut: true;
            isSigner: false;
        }, {
            name: "coinVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "pcVault";
            isMut: true;
            isSigner: false;
        }, {
            name: "vaultSigner";
            isMut: false;
            isSigner: false;
        }, {
            name: "tokenProgram";
            isMut: false;
            isSigner: false;
        }, {
            name: "dexProgram";
            isMut: false;
            isSigner: false;
        }];
    }];
    args: [];
} & {
    name: "settleSpotFunds";
}>;
export declare const makeUpdateTokenIndexIx: (client: CypherClient, cacheAccount: PublicKey, pool: PublicKey, poolNodes: PublicKey[]) => Promise<TransactionInstruction>;
export declare const makeUpdateFundingRateIx: (client: CypherClient, cacheAccount: PublicKey, market: PublicKey, orderbook: PublicKey, bids: PublicKey, asks: PublicKey) => Promise<TransactionInstruction>;
export declare const makeConsumeFuturesEventsIx: (client: CypherClient, clearing: PublicKey, market: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, openOrders: PublicKey[], limit: number) => Promise<TransactionInstruction>;
export declare const makeConsumePerpEventsIx: (client: CypherClient, clearing: PublicKey, market: PublicKey, orderbook: PublicKey, eventQueue: PublicKey, openOrders: PublicKey[], limit: number) => Promise<TransactionInstruction>;
export declare const makeEditSubAccountMarginIx: (client: CypherClient, masterAccount: PublicKey, subAccount: PublicKey, authority: PublicKey, marginingType: SubAccountMargining) => Promise<TransactionInstruction>;
export declare const makeUpdateAccountMarginIx: (client: CypherClient, cacheAccount: PublicKey, masterAccount: PublicKey, signer: PublicKey, subAccounts: PublicKey[]) => Promise<TransactionInstruction>;
export declare const makeTransferBetweenSubAccountsIx: (client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, masterAccount: PublicKey, fromSubAccount: PublicKey, toSubAccount: PublicKey, assetMint: PublicKey, assetPoolNode: PublicKey, authority: PublicKey, amount: BN) => Promise<TransactionInstruction>;
export declare const makeDepositDeliverableIx: (client: CypherClient, market: PublicKey, pool: PublicKey, poolNode: PublicKey, tokenMint: PublicKey, tokenVault: PublicKey, sourceTokenAccount: PublicKey, authority: PublicKey, amount: BN) => Promise<TransactionInstruction>;
export declare const makeSettlePositionIx: (client: CypherClient, cacheAccount: PublicKey, masterAccount: PublicKey, subAccount: PublicKey, market: PublicKey, quotePoolNode: PublicKey) => Promise<TransactionInstruction>;
export declare const makeCreateMarketAccountsIxs: (client: CypherClient) => Promise<{
    orderbook: PublicKey;
    eventQueue: PublicKey;
    bids: PublicKey;
    asks: PublicKey;
    priceHistory: PublicKey;
    ixs: TransactionInstruction[];
    signers: Keypair[];
}>;
export declare const makeRequestCuIx: (payer: PublicKey, units: number) => TransactionInstruction;
export declare const makeCreateMintIxs: (provider: AnchorProvider, authority: PublicKey, mint: PublicKey, decimals?: number) => Promise<TransactionInstruction[]>;
export declare const makeCreateTokenAccountIxs: (provider: AnchorProvider, newAccountPubkey: PublicKey, mint: PublicKey, owner: PublicKey, lamports?: number) => Promise<TransactionInstruction[]>;
