"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uiToSplPrice = exports.uiToSplAmountFixed = exports.uiToSplAmount = exports.splToUiPrice = exports.splToUiAmountFixed = exports.splToUiAmount = exports.getQuoteFromBase = exports.fp32Mul = exports.priceLotsToNative = exports.sizeLotsToNative = exports.getSideFromKey = void 0;
const mango_client_1 = require("@blockworks-foundation/mango-client");
const anchor_1 = require("@project-serum/anchor");
const on_chain_1 = require("../types/on-chain");
function getSideFromKey(orderId) {
    const orderIdSideFlag = new anchor_1.BN(1).shln(63);
    const and = orderIdSideFlag.and(orderId);
    try {
        if (and.toNumber() !== 0) {
            return on_chain_1.Side.Bid;
        }
        else {
            return on_chain_1.Side.Ask;
        }
    }
    catch (e) {
        return on_chain_1.Side.Bid;
    }
}
exports.getSideFromKey = getSideFromKey;
function sizeLotsToNative(sizeLots, baseMultiplier) {
    return sizeLots.mul(baseMultiplier);
}
exports.sizeLotsToNative = sizeLotsToNative;
function priceLotsToNative(priceLots, baseMultiplier, quoteMultiplier, decimals) {
    return priceLots
        .mul(quoteMultiplier)
        .mul(new anchor_1.BN(10 ** decimals))
        .div(baseMultiplier);
}
exports.priceLotsToNative = priceLotsToNative;
function fp32Mul(a, bFp32) {
    return a.mul(bFp32).ushrn(32);
}
exports.fp32Mul = fp32Mul;
function getQuoteFromBase(baseAmount, scaledPriceFp32, baseMultiplier, quoteMultiplier) {
    return fp32Mul(baseAmount, scaledPriceFp32)
        .mul(quoteMultiplier)
        .div(baseMultiplier);
}
exports.getQuoteFromBase = getQuoteFromBase;
function splToUiAmount(splAmount, decimals) {
    return splAmount.toNumber() / 10 ** decimals;
}
exports.splToUiAmount = splToUiAmount;
function splToUiAmountFixed(splAmount, decimals) {
    return splAmount.div(mango_client_1.I80F48.fromNumber(10 ** decimals));
}
exports.splToUiAmountFixed = splToUiAmountFixed;
function splToUiPrice(splPrice, baseDecimals, quoteDecimals) {
    return (splPrice.toNumber() * 10 ** baseDecimals) / 10 ** quoteDecimals;
}
exports.splToUiPrice = splToUiPrice;
function uiToSplAmount(uiAmount, decimals) {
    return new anchor_1.BN(uiAmount * 10 ** decimals);
}
exports.uiToSplAmount = uiToSplAmount;
function uiToSplAmountFixed(uiAmount, decimals) {
    return mango_client_1.I80F48.fromNumber(uiAmount).mul(mango_client_1.I80F48.fromNumber(10 ** decimals));
}
exports.uiToSplAmountFixed = uiToSplAmountFixed;
function uiToSplPrice(uiPrice, baseDecimals, quoteDecimals) {
    return new anchor_1.BN(uiPrice * 10 ** quoteDecimals).divn(10 ** baseDecimals);
}
exports.uiToSplPrice = uiToSplPrice;
//# sourceMappingURL=tokenAmount.js.map