/// <reference types="node" />
import { EventQueue, Slab } from '@chugach-foundation/aaob';
import { FuturesMarket } from '../accounts';
import { ErrorCB, EventQueueListenerCB, Fills, FillsExtended, FillsListenerCB, OrderbookListenerCB, ParsedOrderbook } from '../types';
import { CypherClient } from '../client/index';
import { PublicKey } from '@solana/web3.js';
import { DerivativesMarket } from './derivativesMarket';
export declare class FuturesMarketViewer implements DerivativesMarket {
    readonly client: CypherClient;
    readonly market: FuturesMarket;
    private _bidsListener;
    private _asksListener;
    private _eventQueueListener;
    private _fillsListener;
    constructor(client: CypherClient, market: FuturesMarket);
    private get connection();
    get address(): PublicKey;
    /**
     * Parses the given buffer into the Slab structure
     * @param data the account info data buffer
     * @param increasing whether the data should be returned in increasing order
     * @param orderbookDepth number of levels of slab data to process
     */
    orderbookParser(data: Buffer, increasing: boolean, orderbookDepth?: number): ParsedOrderbook;
    eventQueueParser(data: Buffer): EventQueue;
    fillsParser(data: Buffer): FillsExtended;
    addBidsListener(callback: OrderbookListenerCB, errorCallback?: ErrorCB, orderbookDepth?: number): void;
    removeBidsListener(): void;
    addAsksListener(callback: OrderbookListenerCB, errorCallback?: ErrorCB, orderbookDepth?: number): void;
    removeAsksListener(): void;
    addEventQueueListener(callback: EventQueueListenerCB, errorCallback: ErrorCB): void;
    removeEventQueueListener(): void;
    addFillsListener(callback: FillsListenerCB, errorCallback: ErrorCB): void;
    removeFillsListener(): void;
    calcMarketOrderPrice(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    calcMarketOrderPriceForAvailableAmount(size: number, side: 'buy' | 'sell', bids: ParsedOrderbook, asks: ParsedOrderbook): number[];
    getTopAskPrice(asks: ParsedOrderbook): number;
    getlastPrice(fills: Fills): number;
    getMiddlePointPrice(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getContractsOnOrderbooks(bids: ParsedOrderbook, asks: ParsedOrderbook): number;
    getOrderBook(): Promise<{
        bids: ParsedOrderbook;
        asks: ParsedOrderbook;
    }>;
    getOrderBookFull(): Promise<{
        bids: Slab;
        asks: Slab;
    }>;
    loadFills(): Promise<Fills>;
    private loadEventQueue;
}
